"use strict";

const { images_url } = require("../constants");
const KuadradoValues = require("./home-page-components/kuadrado-values");
const NewsArticles = require("./home-page-components/news-articles");
const ThemeCard = require("./home-page-components/theme-card");
const WhoAmI = require("./home-page-components/whoami");
const WebPage = require("./lib/web-page");

class HomePage extends WebPage {
    render() {
        return {
            tag: "div",
            id: "home-page",
            contents: [
                {
                    tag: "div",
                    class: "page-header",
                    contents: [
                        {
                            tag: "div",
                            class: "big-logo page-contents-center",
                            contents: [
                                {
                                    tag: "img",
                                    alt: "logo Kuadrado",
                                    src: `${images_url}logo_kuadrado.svg`,
                                },
                                {
                                    tag: "img",
                                    class: "logo-text",
                                    alt: "Kuadrado",
                                    src: `${images_url}logo_kuadrado_txt.svg`,
                                },
                            ],
                        },
                        { tag: "h1", contents: "Kuadrado Software", class: "page-contents-center" },
                        {
                            tag: "p",
                            class: "page-contents-center",
                            contents: `Créations numériques, jeux vidéos, web, software et pédagogie.`,
                        },
                        {
                            tag: "ul",
                            class: "philo-bubbles",
                            contents: ["Simplicité", "Légèreté", "Écologie"].map(word => {
                                return {
                                    tag: "li",
                                    contents: [{ tag: "span", contents: word }],
                                };
                            }),
                        },
                    ],
                },
                {
                    tag: "section",
                    class: "page-contents-center poles",
                    contents: [
                        {
                            title: "Jeux",
                            img: "game_controller.svg",
                            href: "/games/",
                            description:
                                "Créations vidéoludiques, jeux web et jeux PC, projets en cours.",
                        },
                        {
                            title: "Pédagogie",
                            img: "brain.svg",
                            href: "/education/",
                            description: `S'approprier la technologie par le partage de connaissances.`,
                        },
                        {
                            title: "Software",
                            img: "meca_proc.svg",
                            href: "/software-development/",
                            description: `R&D, projets expérimentaux, web et outillage logiciel`,
                        },
                    ].map(cardProps => new ThemeCard(cardProps).render()),
                },
                {
                    tag: "section",
                    class: "page-philo",
                    contents: [
                        {
                            tag: "p",
                            class: "page-contents-center",
                            contents: `Travailler pour le plaisir de créer, de maîtriser et de comprendre.`,
                        },
                    ],
                },
                {
                    tag: "section",
                    class: "page-contents-center",
                    id:"news",
                    contents: [
                        { tag: "h2", contents: "Actu", class: "section-title" },
                        new NewsArticles().render(),
                    ],
                },
                new KuadradoValues().render(),
                new WhoAmI().render(),
            ],
        };
    }
}

module.exports = HomePage;
